@@ -417,6 +417,7 @@ tracker_data_ontology_load_statement (const gchar *ontology_path,
 					tracker_property_set_indexed (property, FALSE);
 					tracker_property_set_secondary_index (property, NULL);
 					tracker_property_set_writeback (property, FALSE);
+					tracker_property_set_default_value (property, NULL);
 				}
 				return;
 			}
@@ -692,6 +693,16 @@ tracker_data_ontology_load_statement (const gchar *ontology_path,
 		if (strcmp (object, "true") == 0) {
 			tracker_property_set_fulltext_no_limit (property, TRUE);
 		}
+	} else if (g_strcmp0 (predicate, TRACKER_PREFIX "defaultValue") == 0) {
+		TrackerProperty *property;
+
+		property = tracker_ontologies_get_property_by_uri (subject);
+		if (property == NULL) {
+			g_critical ("%s: Unknown property %s", ontology_path, subject);
+			return;
+		}
+
+		tracker_property_set_default_value (property, object);
 	} else if (g_strcmp0 (predicate, TRACKER_PREFIX "prefix") == 0) {
 		TrackerNamespace *namespace;
 
@@ -831,6 +842,16 @@ tracker_data_ontology_process_changes (GPtrArray *seen_classes,
 				tracker_class_set_db_schema_changed (class, TRUE);
 				tracker_property_set_db_schema_changed (property, TRUE);
 			}
+
+			if (update_property_value ("tracker:defaultValue", subject, TRACKER_PREFIX "defaultValue",
+			                           tracker_property_get_default_value (property),
+			                           NULL, NULL, property)) {
+				TrackerClass *class;
+
+				class = tracker_property_get_domain (property);
+				tracker_class_set_db_schema_changed (class, TRUE);
+				tracker_property_set_db_schema_changed (property, TRUE);
+			}
 		}
 	}
 }
@@ -1172,11 +1193,19 @@ class_add_super_classes_from_db (TrackerDBInterface *iface,
 {
 	TrackerDBStatement *stmt;
 	TrackerDBCursor *cursor;
+	GError *error = NULL;
 
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdfs:subClassOf\") "
 	                                              "FROM \"rdfs:Class_rdfs:subClassOf\" "
 	                                              "WHERE ID = (SELECT ID FROM Resource WHERE Uri = ?)");
+
+	if (!stmt) {
+		g_critical ("%s", error->message);
+		g_error_free (error);
+		return;
+	}
+
 	tracker_db_statement_bind_text (stmt, 0, tracker_class_get_uri (class));
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -1186,7 +1215,7 @@ class_add_super_classes_from_db (TrackerDBInterface *iface,
 			TrackerClass *super_class;
 			const gchar *super_class_uri;
 
-			super_class_uri = tracker_db_cursor_get_string (cursor, 0);
+			super_class_uri = tracker_db_cursor_get_string (cursor, 0, NULL);
 			super_class = tracker_ontologies_get_class_by_uri (super_class_uri);
 			tracker_class_add_super_class (class, super_class);
 		}
@@ -1201,11 +1230,19 @@ property_add_super_properties_from_db (TrackerDBInterface *iface,
 {
 	TrackerDBStatement *stmt;
 	TrackerDBCursor *cursor;
+	GError *error = NULL;
 
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdfs:subPropertyOf\") "
 	                                              "FROM \"rdf:Property_rdfs:subPropertyOf\" "
 	                                              "WHERE ID = (SELECT ID FROM Resource WHERE Uri = ?)");
+
+	if (!stmt) {
+		g_critical ("%s", error->message);
+		g_error_free (error);
+		return;
+	}
+
 	tracker_db_statement_bind_text (stmt, 0, tracker_property_get_uri (property));
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -1215,7 +1252,7 @@ property_add_super_properties_from_db (TrackerDBInterface *iface,
 			TrackerProperty *super_property;
 			const gchar *super_property_uri;
 
-			super_property_uri = tracker_db_cursor_get_string (cursor, 0);
+			super_property_uri = tracker_db_cursor_get_string (cursor, 0, NULL);
 			super_property = tracker_ontologies_get_property_by_uri (super_property_uri);
 			tracker_property_add_super_property (property, super_property);
 		}
@@ -1228,25 +1265,29 @@ static void
 db_get_static_data (TrackerDBInterface *iface)
 {
 	TrackerDBStatement *stmt;
-	TrackerDBCursor *cursor;
+	TrackerDBCursor *cursor = NULL;
 	TrackerDBResultSet *result_set;
+	GError *error = NULL;
 
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT (SELECT Uri FROM Resource WHERE ID = \"tracker:Ontology\".ID), "
 	                                              "\"nao:lastModified\" "
 	                                              "FROM \"tracker:Ontology\"");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		while (tracker_db_cursor_iter_next (cursor, NULL)) {
+		while (tracker_db_cursor_iter_next (cursor, &error)) {
 			TrackerOntology *ontology;
 			const gchar     *uri;
 			time_t           last_mod;
 
 			ontology = tracker_ontology_new ();
 
-			uri = tracker_db_cursor_get_string (cursor, 0);
+			uri = tracker_db_cursor_get_string (cursor, 0, NULL);
 			last_mod = (time_t) tracker_db_cursor_get_int (cursor, 1);
 
 			tracker_ontology_set_is_new (ontology, FALSE);
@@ -1258,24 +1299,33 @@ db_get_static_data (TrackerDBInterface *iface)
 		}
 
 		g_object_unref (cursor);
+		cursor = NULL;
 	}
 
-	stmt = tracker_db_interface_create_statement (iface,
+	if (error) {
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
+	}
+
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT (SELECT Uri FROM Resource WHERE ID = \"tracker:Namespace\".ID), "
 	                                              "\"tracker:prefix\" "
 	                                              "FROM \"tracker:Namespace\"");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		while (tracker_db_cursor_iter_next (cursor, NULL)) {
+		while (tracker_db_cursor_iter_next (cursor, &error)) {
 			TrackerNamespace *namespace;
 			const gchar      *uri, *prefix;
 
 			namespace = tracker_namespace_new ();
 
-			uri = tracker_db_cursor_get_string (cursor, 0);
-			prefix = tracker_db_cursor_get_string (cursor, 1);
+			uri = tracker_db_cursor_get_string (cursor, 0, NULL);
+			prefix = tracker_db_cursor_get_string (cursor, 1, NULL);
 
 			tracker_namespace_set_is_new (namespace, FALSE);
 			tracker_namespace_set_uri (namespace, uri);
@@ -1287,18 +1337,27 @@ db_get_static_data (TrackerDBInterface *iface)
 		}
 
 		g_object_unref (cursor);
+		cursor = NULL;
 	}
 
-	stmt = tracker_db_interface_create_statement (iface,
+	if (error) {
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
+	}
+
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT \"rdfs:Class\".ID, "
 	                                              "(SELECT Uri FROM Resource WHERE ID = \"rdfs:Class\".ID), "
 	                                              "\"tracker:notify\" "
 	                                              "FROM \"rdfs:Class\" ORDER BY ID");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		while (tracker_db_cursor_iter_next (cursor, NULL)) {
+		while (tracker_db_cursor_iter_next (cursor, &error)) {
 			TrackerClass *class;
 			const gchar  *uri;
 			gint          id;
@@ -1309,12 +1368,12 @@ db_get_static_data (TrackerDBInterface *iface)
 			class = tracker_class_new ();
 
 			id = tracker_db_cursor_get_int (cursor, 0);
-			uri = tracker_db_cursor_get_string (cursor, 1);
+			uri = tracker_db_cursor_get_string (cursor, 1, NULL);
 
 			tracker_db_cursor_get_value (cursor, 2, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				notify = (g_value_get_int (&value) == 1);
+				notify = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
@@ -1335,21 +1394,33 @@ db_get_static_data (TrackerDBInterface *iface)
 			/* xsd classes do not derive from rdfs:Resource and do not use separate tables */
 			if (!g_str_has_prefix (tracker_class_get_name (class), "xsd:")) {
 				/* update statistics */
-				stmt = tracker_db_interface_create_statement (iface, "SELECT COUNT(1) FROM \"%s\"", tracker_class_get_name (class));
-				result_set = tracker_db_statement_execute (stmt, NULL);
-				tracker_db_result_set_get (result_set, 0, &count, -1);
-				tracker_class_set_count (class, count);
-				g_object_unref (result_set);
-				g_object_unref (stmt);
+				stmt = tracker_db_interface_create_statement (iface, &error, "SELECT COUNT(1) FROM \"%s\"", tracker_class_get_name (class));
+
+				if (error) {
+					g_warning ("%s", error->message);
+					g_clear_error (&error);
+				} else {
+					result_set = tracker_db_statement_execute (stmt, NULL);
+					tracker_db_result_set_get (result_set, 0, &count, -1);
+					tracker_class_set_count (class, count);
+					g_object_unref (result_set);
+					g_object_unref (stmt);
+				}
 			}
 
 			g_object_unref (class);
 		}
 
 		g_object_unref (cursor);
+		cursor = NULL;
 	}
 
-	stmt = tracker_db_interface_create_statement (iface,
+	if (error) {
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
+	}
+
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT \"rdf:Property\".ID, (SELECT Uri FROM Resource WHERE ID = \"rdf:Property\".ID), "
 	                                              "(SELECT Uri FROM Resource WHERE ID = \"rdfs:domain\"), "
 	                                              "(SELECT Uri FROM Resource WHERE ID = \"rdfs:range\"), "
@@ -1362,16 +1433,20 @@ db_get_static_data (TrackerDBInterface *iface)
 	                                              "\"tracker:isAnnotation\", "
 	                                              "\"tracker:writeback\", "
 	                                              "(SELECT 1 FROM \"rdfs:Resource_rdf:type\" WHERE ID = \"rdf:Property\".ID AND "
-	                                              "\"rdf:type\" = (SELECT ID FROM Resource WHERE Uri = '" NRL_INVERSE_FUNCTIONAL_PROPERTY "')) "
+	                                              "\"rdf:type\" = (SELECT ID FROM Resource WHERE Uri = '" NRL_INVERSE_FUNCTIONAL_PROPERTY "')), "
+	                                              "\"tracker:defaultValue\" "
 	                                              "FROM \"rdf:Property\" ORDER BY ID");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		while (tracker_db_cursor_iter_next (cursor, NULL)) {
+		while (tracker_db_cursor_iter_next (cursor, &error)) {
 			GValue value = { 0 };
 			TrackerProperty *property;
-			const gchar     *uri, *domain_uri, *range_uri, *secondary_index_uri;
+			const gchar     *uri, *domain_uri, *range_uri, *secondary_index_uri, *default_value;
 			gboolean         multi_valued, indexed, fulltext_indexed, fulltext_no_limit;
 			gboolean         transient, annotation, is_inverse_functional_property;
 			gboolean         writeback;
@@ -1380,14 +1455,14 @@ db_get_static_data (TrackerDBInterface *iface)
 			property = tracker_property_new ();
 
 			id = tracker_db_cursor_get_int (cursor, 0);
-			uri = tracker_db_cursor_get_string (cursor, 1);
-			domain_uri = tracker_db_cursor_get_string (cursor, 2);
-			range_uri = tracker_db_cursor_get_string (cursor, 3);
+			uri = tracker_db_cursor_get_string (cursor, 1, NULL);
+			domain_uri = tracker_db_cursor_get_string (cursor, 2, NULL);
+			range_uri = tracker_db_cursor_get_string (cursor, 3, NULL);
 
 			tracker_db_cursor_get_value (cursor, 4, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				multi_valued = (g_value_get_int (&value) > 1);
+				multi_valued = (g_value_get_int64 (&value) > 1);
 				g_value_unset (&value);
 			} else {
 				/* nrl:maxCardinality not set
@@ -1398,19 +1473,19 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_db_cursor_get_value (cursor, 5, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				indexed = (g_value_get_int (&value) == 1);
+				indexed = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
 				indexed = FALSE;
 			}
 
-			secondary_index_uri = tracker_db_cursor_get_string (cursor, 6);
+			secondary_index_uri = tracker_db_cursor_get_string (cursor, 6, NULL);
 
 			tracker_db_cursor_get_value (cursor, 7, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				fulltext_indexed = (g_value_get_int (&value) == 1);
+				fulltext_indexed = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
@@ -1420,7 +1495,7 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_db_cursor_get_value (cursor, 8, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				fulltext_no_limit = (g_value_get_int (&value) == 1);
+				fulltext_no_limit = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
@@ -1430,7 +1505,7 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_db_cursor_get_value (cursor, 9, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				transient = (g_value_get_int (&value) == 1);
+				transient = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
@@ -1440,7 +1515,7 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_db_cursor_get_value (cursor, 10, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				annotation = (g_value_get_int (&value) == 1);
+				annotation = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
@@ -1452,7 +1527,7 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_db_cursor_get_value (cursor, 11, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
-				writeback = (g_value_get_int (&value) == 1);
+				writeback = (g_value_get_int64 (&value) == 1);
 				g_value_unset (&value);
 			} else {
 				/* NULL */
@@ -1470,6 +1545,8 @@ db_get_static_data (TrackerDBInterface *iface)
 				is_inverse_functional_property = FALSE;
 			}
 
+			default_value = tracker_db_cursor_get_string (cursor, 13, NULL);
+
 			tracker_property_set_is_new (property, FALSE);
 			tracker_property_set_transient (property, transient);
 			tracker_property_set_uri (property, uri);
@@ -1478,6 +1555,7 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_property_set_range (property, tracker_ontologies_get_class_by_uri (range_uri));
 			tracker_property_set_multiple_values (property, multi_valued);
 			tracker_property_set_indexed (property, indexed);
+			tracker_property_set_default_value (property, default_value);
 
 			tracker_property_set_db_schema_changed (property, FALSE);
 			tracker_property_set_writeback (property, writeback);
@@ -1500,6 +1578,12 @@ db_get_static_data (TrackerDBInterface *iface)
 		}
 
 		g_object_unref (cursor);
+		cursor = NULL;
+	}
+
+	if (error) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
 	}
 }
 
@@ -1512,11 +1596,17 @@ insert_uri_in_resource_table (TrackerDBInterface *iface,
 	TrackerDBStatement *stmt;
 	GError *error = NULL;
 
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "INSERT "
 	                                              "INTO Resource "
 	                                              "(ID, Uri) "
 	                                              "VALUES (?, ?)");
+	if (error) {
+		g_critical ("%s", error->message);
+		g_error_free (error);
+		return;
+	}
+
 	tracker_db_statement_bind_int (stmt, 0, id);
 	tracker_db_statement_bind_text (stmt, 1, uri);
 	tracker_db_statement_execute (stmt, &error);
@@ -1815,8 +1905,12 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 			field_name = tracker_property_get_name (property);
 
 			if (sql_type_for_single_value) {
+				const gchar *default_value;
+
 				/* single value */
 
+				default_value = tracker_property_get_default_value (property);
+
 				if (in_update) {
 					g_debug ("%sAltering database for class '%s' property '%s': single value (%s)",
 					         in_alter ? "" : "  ", 
@@ -1832,6 +1926,13 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 					g_string_append_printf (create_sql, ", \"%s\" %s",
 					                        field_name,
 					                        sql_type_for_single_value);
+
+					/* add DEFAULT in case that the ontology specifies a default value,
+					   assumes that default values never contain quotes */
+					if (default_value != NULL) {
+						g_string_append_printf (create_sql, " DEFAULT '%s'", default_value);
+					}
+
 					if (tracker_property_get_is_inverse_functional_property (property)) {
 						g_string_append (create_sql, " UNIQUE");
 					}
@@ -1858,6 +1959,12 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 					                        service_name,
 					                        field_name,
 					                        sql_type_for_single_value);
+
+					/* add DEFAULT in case that the ontology specifies a default value,
+					   assumes that default values never contain quotes */
+					if (default_value != NULL) {
+						g_string_append_printf (alter_sql, " DEFAULT '%s'", default_value);
+					}
 					if (tracker_property_get_is_inverse_functional_property (property)) {
 						g_string_append (alter_sql, " UNIQUE");
 					}
@@ -2100,26 +2207,35 @@ get_ontologies (gboolean     test_schema,
 static gint
 get_new_service_id (TrackerDBInterface *iface)
 {
-	TrackerDBCursor    *cursor;
+	TrackerDBCursor    *cursor = NULL;
 	TrackerDBStatement *stmt;
 	gint max_service_id = 0;
+	GError *error = NULL;
 
 	/* Don't intermix this thing with tracker_data_update_get_new_service_id,
 	 * if you use this, know what you are doing! */
 
 	iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT MAX(ID) AS A FROM Resource");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		tracker_db_cursor_iter_next (cursor, NULL);
+		tracker_db_cursor_iter_next (cursor, &error);
 		max_service_id = tracker_db_cursor_get_int (cursor, 0);
 		g_object_unref (cursor);
 	}
 
+	if (error) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+	}
+
 	return ++max_service_id;
 }
 
@@ -2203,7 +2319,7 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 
 		/* Read first ontology and commit it into the DB */
 		tracker_data_begin_db_transaction_for_replay (tracker_db_journal_reader_get_time ());
-		tracker_db_interface_sqlite_fts_init (TRACKER_DB_INTERFACE_SQLITE (iface), TRUE);
+		tracker_db_interface_sqlite_fts_init (iface, TRUE);
 		tracker_data_ontology_import_into_db (FALSE);
 		tracker_data_commit_db_transaction ();
 		tracker_db_journal_reader_shutdown ();
@@ -2259,7 +2375,7 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 		/* Not an ontology transaction: this is the first ontology */
 		tracker_db_journal_start_transaction (time (NULL));
 
-		tracker_db_interface_sqlite_fts_init (TRACKER_DB_INTERFACE_SQLITE (iface), TRUE);
+		tracker_db_interface_sqlite_fts_init (iface, TRUE);
 		tracker_data_ontology_import_into_db (FALSE);
 
 		/* store ontology in database */
@@ -2297,7 +2413,7 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 		create_decomposed_transient_metadata_tables (iface);
 		check_ontology = TRUE;
 
-		tracker_db_interface_sqlite_fts_init (TRACKER_DB_INTERFACE_SQLITE (iface), FALSE);
+		tracker_db_interface_sqlite_fts_init (iface, FALSE);
 	}
 
 	if (check_ontology) {
@@ -2306,6 +2422,7 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 		guint p;
 		GPtrArray *seen_classes;
 		GPtrArray *seen_properties;
+		GError *error = NULL;
 
 		seen_classes = g_ptr_array_new ();
 		seen_properties = g_ptr_array_new ();
@@ -2344,30 +2461,41 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 		 * for all the ontology files in ontologies_dir whether the last-modified
 		 * has changed since we dealt with the file last time. */
 
-		stmt = tracker_db_interface_create_statement (iface,
+		stmt = tracker_db_interface_create_statement (iface, &error,
 		        "SELECT Resource.Uri, \"rdfs:Resource\".\"nao:lastModified\" FROM \"tracker:Ontology\""
 		        "INNER JOIN Resource ON Resource.ID = \"tracker:Ontology\".ID "
 		        "INNER JOIN \"rdfs:Resource\" ON \"tracker:Ontology\".ID = \"rdfs:Resource\".ID");
 
-		cursor = tracker_db_statement_start_cursor (stmt, NULL);
-		g_object_unref (stmt);
+		if (stmt) {
+			cursor = tracker_db_statement_start_cursor (stmt, &error);
+			g_object_unref (stmt);
+		} else {
+			cursor = NULL;
+		}
 
 		ontos_table = g_hash_table_new_full (g_str_hash,
 		                                     g_str_equal,
 		                                     g_free,
 		                                     NULL);
 
-		while (tracker_db_cursor_iter_next (cursor, NULL)) {
-			const gchar *onto_uri = tracker_db_cursor_get_string (cursor, 0);
-			/* It's stored as an int in the db anyway. This is caused by
-			 * string_to_gvalue in tracker-data-update.c */
-			gint value = tracker_db_cursor_get_int (cursor, 1);
+		if (cursor) {
+			while (tracker_db_cursor_iter_next (cursor, &error)) {
+				const gchar *onto_uri = tracker_db_cursor_get_string (cursor, 0, NULL);
+				/* It's stored as an int in the db anyway. This is caused by
+				 * string_to_gvalue in tracker-data-update.c */
+				gint value = tracker_db_cursor_get_int (cursor, 1);
 
-			g_hash_table_insert (ontos_table, g_strdup (onto_uri),
-			                     GINT_TO_POINTER (value));
+				g_hash_table_insert (ontos_table, g_strdup (onto_uri),
+				                     GINT_TO_POINTER (value));
+			}
+
+			g_object_unref (cursor);
 		}
 
-		g_object_unref (cursor);
+		if (error) {
+			g_warning ("%s", error->message);
+			g_clear_error (&error);
+		}
 
 		for (l = ontos; l; l = l->next) {
 			TrackerOntology *ontology;
@@ -2430,17 +2558,24 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 
 			if (update_nao) {
 				/* Update the nao:lastModified in the database */
-				stmt = tracker_db_interface_create_statement (iface,
+				stmt = tracker_db_interface_create_statement (iface, &error,
 				        "UPDATE \"rdfs:Resource\" SET \"nao:lastModified\"= ? "
 				        "WHERE \"rdfs:Resource\".ID = "
 				        "(SELECT Resource.ID FROM Resource INNER JOIN \"rdfs:Resource\" "
 				        "ON \"rdfs:Resource\".ID = Resource.ID WHERE "
 				        "Resource.Uri = ?)");
 
-				tracker_db_statement_bind_int (stmt, 0, last_mod);
-				tracker_db_statement_bind_text (stmt, 1, ontology_uri);
-				tracker_db_statement_execute (stmt, NULL);
-				g_object_unref (stmt);
+				if (stmt) {
+					tracker_db_statement_bind_int (stmt, 0, last_mod);
+					tracker_db_statement_bind_text (stmt, 1, ontology_uri);
+					tracker_db_statement_execute (stmt, &error);
+					g_object_unref (stmt);
+				}
+
+				if (error) {
+					g_critical ("%s", error->message);
+					g_clear_error (&error);
+				}
 			}
 
 			g_object_unref (ontology);
@@ -2502,18 +2637,22 @@ tracker_data_manager_get_db_option_int64 (const gchar *option)
 {
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
-	TrackerDBResultSet *result_set;
+	TrackerDBResultSet *result_set = NULL;
 	gchar              *str;
 	gint                value = 0;
+	GError             *error = NULL;
 
 	g_return_val_if_fail (option != NULL, 0);
 
 	iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (iface, "SELECT OptionValue FROM Options WHERE OptionKey = ?");
-	tracker_db_statement_bind_text (stmt, 0, option);
-	result_set = tracker_db_statement_execute (stmt, NULL);
-	g_object_unref (stmt);
+	stmt = tracker_db_interface_create_statement (iface, &error, "SELECT OptionValue FROM Options WHERE OptionKey = ?");
+
+	if (stmt) {
+		tracker_db_statement_bind_text (stmt, 0, option);
+		result_set = tracker_db_statement_execute (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (result_set) {
 		tracker_db_result_set_get (result_set, 0, &str, -1);
@@ -2526,6 +2665,12 @@ tracker_data_manager_get_db_option_int64 (const gchar *option)
 		g_object_unref (result_set);
 	}
 
+	if (error) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+		return -1;
+	}
+
 	return value;
 }
 
@@ -2536,20 +2681,30 @@ tracker_data_manager_set_db_option_int64 (const gchar *option,
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
 	gchar              *str;
+	GError             *error = NULL;
 
 	g_return_if_fail (option != NULL);
 
 	iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (iface, "REPLACE INTO Options (OptionKey, OptionValue) VALUES (?,?)");
-	tracker_db_statement_bind_text (stmt, 0, option);
+	stmt = tracker_db_interface_create_statement (iface, &error, "REPLACE INTO Options (OptionKey, OptionValue) VALUES (?,?)");
 
-	str = g_strdup_printf ("%"G_GINT64_FORMAT, value);
-	tracker_db_statement_bind_text (stmt, 1, str);
-	g_free (str);
+	if (stmt) {
+		tracker_db_statement_bind_text (stmt, 0, option);
 
-	tracker_db_statement_execute (stmt, NULL);
-	g_object_unref (stmt);
+		str = g_strdup_printf ("%"G_GINT64_FORMAT, value);
+		tracker_db_statement_bind_text (stmt, 1, str);
+		g_free (str);
+
+		tracker_db_statement_execute (stmt, &error);
+		g_object_unref (stmt);
+	}
+
+	if (error) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+		return;
+	}
 }
 
 gboolean
@@ -2557,3 +2712,9 @@ tracker_data_manager_interrupt_thread (GThread *thread)
 {
 	return tracker_db_manager_interrupt_thread (thread);
 }
+
+void
+tracker_data_manager_interrupt_thread_reset (GThread *thread)
+{
+	tracker_db_manager_interrupt_thread_reset (thread);
+}
