@@ -330,9 +330,10 @@ GQuark tracker_data_error_quark (void) {
 static gint
 tracker_data_update_get_new_service_id (void)
 {
-	TrackerDBCursor    *cursor;
+	TrackerDBCursor    *cursor = NULL;
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
+	GError *error = NULL;
 
 	if (G_LIKELY (max_service_id != 0)) {
 		return ++max_service_id;
@@ -340,17 +341,27 @@ tracker_data_update_get_new_service_id (void)
 
 	iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT MAX(ID) AS A FROM Resource");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		tracker_db_cursor_iter_next (cursor, NULL);
-		max_service_id = MAX (tracker_db_cursor_get_int (cursor, 0), max_service_id);
+		if (tracker_db_cursor_iter_next (cursor, &error)) {
+			max_service_id = MAX (tracker_db_cursor_get_int (cursor, 0), max_service_id);
+		}
+
 		g_object_unref (cursor);
 	}
 
+	if (G_UNLIKELY (error)) {
+		g_warning ("Could not get new resource ID: %s\n", error->message);
+		g_error_free (error);
+	}
+
 	return ++max_service_id;
 }
 
@@ -364,9 +375,10 @@ tracker_data_update_shutdown (void)
 static gint
 tracker_data_update_get_next_modseq (void)
 {
-	TrackerDBCursor    *cursor;
+	TrackerDBCursor    *cursor = NULL;
 	TrackerDBInterface *temp_iface;
 	TrackerDBStatement *stmt;
+	GError             *error = NULL;
 
 	if (G_LIKELY (max_modseq != 0)) {
 		return ++max_modseq;
@@ -374,17 +386,27 @@ tracker_data_update_get_next_modseq (void)
 
 	temp_iface = tracker_db_manager_get_db_interface ();
 
-	stmt = tracker_db_interface_create_statement (temp_iface,
+	stmt = tracker_db_interface_create_statement (temp_iface, &error,
 	                                              "SELECT MAX(\"tracker:modified\") AS A FROM \"rdfs:Resource\"");
-	cursor = tracker_db_statement_start_cursor (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		cursor = tracker_db_statement_start_cursor (stmt, &error);
+		g_object_unref (stmt);
+	}
 
 	if (cursor) {
-		tracker_db_cursor_iter_next (cursor, NULL);
-		max_modseq = MAX (tracker_db_cursor_get_int (cursor, 0), max_modseq);
+		if (tracker_db_cursor_iter_next (cursor, &error)) {
+			max_modseq = MAX (tracker_db_cursor_get_int (cursor, 0), max_modseq);
+		}
+
 		g_object_unref (cursor);
 	}
 
+	if (G_UNLIKELY (error)) {
+		g_warning ("Could not get new resource ID: %s\n", error->message);
+		g_error_free (error);
+	}
+
 	return ++max_modseq;
 }
 
@@ -523,7 +545,7 @@ ensure_resource_id (const gchar *uri,
 {
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
-
+	GError *error = NULL;
 	gint id;
 
 	id = query_resource_id (uri);
@@ -536,11 +558,19 @@ ensure_resource_id (const gchar *uri,
 		iface = tracker_db_manager_get_db_interface ();
 
 		id = tracker_data_update_get_new_service_id ();
-		stmt = tracker_db_interface_create_statement (iface, "INSERT INTO Resource (ID, Uri) VALUES (?, ?)");
-		tracker_db_statement_bind_int (stmt, 0, id);
-		tracker_db_statement_bind_text (stmt, 1, uri);
-		tracker_db_statement_execute (stmt, NULL);
-		g_object_unref (stmt);
+		stmt = tracker_db_interface_create_statement (iface, &error, "INSERT INTO Resource (ID, Uri) VALUES (?, ?)");
+
+		if (stmt) {
+			tracker_db_statement_bind_int (stmt, 0, id);
+			tracker_db_statement_bind_text (stmt, 1, uri);
+			tracker_db_statement_execute (stmt, &error);
+			g_object_unref (stmt);
+		}
+
+		if (error) {
+			g_critical ("Could not ensure resource existence: %s", error->message);
+			g_error_free (error);
+		}
 
 		if (!in_journal_replay) {
 			tracker_db_journal_append_resource (id, uri);
@@ -564,18 +594,15 @@ statement_bind_gvalue (TrackerDBStatement *stmt,
 	case G_TYPE_STRING:
 		tracker_db_statement_bind_text (stmt, (*idx)++, g_value_get_string (value));
 		break;
-	case G_TYPE_INT:
-		tracker_db_statement_bind_int (stmt, (*idx)++, g_value_get_int (value));
-		break;
 	case G_TYPE_INT64:
-		tracker_db_statement_bind_int64 (stmt, (*idx)++, g_value_get_int64 (value));
+		tracker_db_statement_bind_int (stmt, (*idx)++, g_value_get_int64 (value));
 		break;
 	case G_TYPE_DOUBLE:
 		tracker_db_statement_bind_double (stmt, (*idx)++, g_value_get_double (value));
 		break;
 	default:
 		if (type == TRACKER_TYPE_DATE_TIME) {
-			tracker_db_statement_bind_int64 (stmt, (*idx)++, tracker_date_time_get_time (value));
+			tracker_db_statement_bind_int (stmt, (*idx)++, tracker_date_time_get_time (value));
 			tracker_db_statement_bind_int (stmt, (*idx)++, tracker_date_time_get_local_date (value));
 			tracker_db_statement_bind_int (stmt, (*idx)++, tracker_date_time_get_local_time (value));
 		} else {
@@ -626,12 +653,12 @@ tracker_data_resource_buffer_flush (GError **error)
 
 				if (table->delete_value) {
 					/* delete rows for multiple value properties */
-					stmt = tracker_db_interface_create_statement (iface,
+					stmt = tracker_db_interface_create_statement (iface, &actual_error,
 					                                              "DELETE FROM \"%s\" WHERE ID = ? AND \"%s\" = ?",
 					                                              table_name,
 					                                              property->name);
 				} else if (property->date_time) {
-					stmt = tracker_db_interface_create_statement (iface,
+					stmt = tracker_db_interface_create_statement (iface, &actual_error,
 					                                              "INSERT OR IGNORE INTO \"%s\" (ID, \"%s\", \"%s:localDate\", \"%s:localTime\", \"%s:graph\") VALUES (?, ?, ?, ?, ?)",
 					                                              table_name,
 					                                              property->name,
@@ -639,13 +666,18 @@ tracker_data_resource_buffer_flush (GError **error)
 					                                              property->name,
 					                                              property->name);
 				} else {
-					stmt = tracker_db_interface_create_statement (iface,
+					stmt = tracker_db_interface_create_statement (iface, &actual_error,
 					                                              "INSERT OR IGNORE INTO \"%s\" (ID, \"%s\", \"%s:graph\") VALUES (?, ?, ?)",
 					                                              table_name,
 					                                              property->name,
 					                                              property->name);
 				}
 
+				if (actual_error) {
+					g_propagate_error (error, actual_error);
+					return;
+				}
+
 				param = 0;
 
 				tracker_db_statement_bind_int (stmt, param++, resource_buffer->id);
@@ -668,11 +700,14 @@ tracker_data_resource_buffer_flush (GError **error)
 		} else {
 			if (table->delete_row) {
 				/* remove entry from rdf:type table */
-				stmt = tracker_db_interface_create_statement (iface, "DELETE FROM \"rdfs:Resource_rdf:type\" WHERE ID = ? AND \"rdf:type\" = ?");
-				tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-				tracker_db_statement_bind_int (stmt, 1, ensure_resource_id (tracker_class_get_uri (table->class), NULL));
-				tracker_db_statement_execute (stmt, &actual_error);
-				g_object_unref (stmt);
+				stmt = tracker_db_interface_create_statement (iface, &actual_error, "DELETE FROM \"rdfs:Resource_rdf:type\" WHERE ID = ? AND \"rdf:type\" = ?");
+
+				if (stmt) {
+					tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+					tracker_db_statement_bind_int (stmt, 1, ensure_resource_id (tracker_class_get_uri (table->class), NULL));
+					tracker_db_statement_execute (stmt, &actual_error);
+					g_object_unref (stmt);
+				}
 
 				if (actual_error) {
 					g_propagate_error (error, actual_error);
@@ -684,10 +719,13 @@ tracker_data_resource_buffer_flush (GError **error)
 				}
 
 				/* remove row from class table */
-				stmt = tracker_db_interface_create_statement (iface, "DELETE FROM \"%s\" WHERE ID = ?", table_name);
-				tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-				tracker_db_statement_execute (stmt, &actual_error);
-				g_object_unref (stmt);
+				stmt = tracker_db_interface_create_statement (iface, &actual_error, "DELETE FROM \"%s\" WHERE ID = ?", table_name);
+
+				if (stmt) {
+					tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+					tracker_db_statement_execute (stmt, &actual_error);
+					g_object_unref (stmt);
+				}
 
 				if (actual_error) {
 					g_propagate_error (error, actual_error);
@@ -700,23 +738,29 @@ tracker_data_resource_buffer_flush (GError **error)
 			if (table->insert) {
 				if (strcmp (table_name, "rdfs:Resource") == 0) {
 					/* ensure we have a row for the subject id */
-					stmt = tracker_db_interface_create_statement (iface,
+					stmt = tracker_db_interface_create_statement (iface, &actual_error,
 						                                      "INSERT OR IGNORE INTO \"%s\" (ID, \"tracker:added\", \"tracker:modified\", Available) VALUES (?, ?, ?, 1)",
 						                                      table_name);
-					tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-					g_warn_if_fail  (resource_time != 0);
-					tracker_db_statement_bind_int64 (stmt, 1, (gint64) resource_time);
-					tracker_db_statement_bind_int (stmt, 3, tracker_data_update_get_next_modseq ());
-					tracker_db_statement_execute (stmt, &actual_error);
-					g_object_unref (stmt);
+
+					if (stmt) {
+						tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+						g_warn_if_fail	(resource_time != 0);
+						tracker_db_statement_bind_int (stmt, 1, (gint64) resource_time);
+						tracker_db_statement_bind_int (stmt, 3, tracker_data_update_get_next_modseq ());
+						tracker_db_statement_execute (stmt, &actual_error);
+						g_object_unref (stmt);
+					}
 				} else {
 					/* ensure we have a row for the subject id */
-					stmt = tracker_db_interface_create_statement (iface,
+					stmt = tracker_db_interface_create_statement (iface, &actual_error,
 						                                      "INSERT OR IGNORE INTO \"%s\" (ID) VALUES (?)",
 						                                      table_name);
-					tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-					tracker_db_statement_execute (stmt, &actual_error);
-					g_object_unref (stmt);
+
+					if (stmt) {
+						tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+						tracker_db_statement_execute (stmt, &actual_error);
+						g_object_unref (stmt);
+					}
 				}
 
 				if (actual_error) {
@@ -749,7 +793,13 @@ tracker_data_resource_buffer_flush (GError **error)
 
 			g_string_append (sql, " WHERE ID = ?");
 
-			stmt = tracker_db_interface_create_statement (iface, "%s", sql->str);
+			stmt = tracker_db_interface_create_statement (iface, &actual_error, "%s", sql->str);
+			g_string_free (sql, TRUE);
+
+			if (actual_error) {
+				g_propagate_error (error, actual_error);
+				return;
+			}
 
 			param = 0;
 			for (i = 0; i < table->properties->len; i++) {
@@ -777,8 +827,6 @@ tracker_data_resource_buffer_flush (GError **error)
 			tracker_db_statement_execute (stmt, &actual_error);
 			g_object_unref (stmt);
 
-			g_string_free (sql, TRUE);
-
 			if (actual_error) {
 				g_propagate_error (error, actual_error);
 				return;
@@ -985,11 +1033,11 @@ cache_create_service_decomposed (TrackerClass *cl,
 
 	g_ptr_array_add (resource_buffer->types, cl);
 
-	g_value_init (&gvalue, G_TYPE_INT);
+	g_value_init (&gvalue, G_TYPE_INT64);
 
 	cache_insert_row (cl);
 
-	g_value_set_int (&gvalue, ensure_resource_id (tracker_class_get_uri (cl), NULL));
+	g_value_set_int64 (&gvalue, ensure_resource_id (tracker_class_get_uri (cl), NULL));
 	cache_insert_value ("rdfs:Resource_rdf:type", "rdf:type", &gvalue,
 	                    graph != NULL ? ensure_resource_id (graph, NULL) : graph_id,
 	                    TRUE, FALSE, FALSE);
@@ -1026,8 +1074,8 @@ value_equal (GValue *value1,
 	switch (type) {
 	case G_TYPE_STRING:
 		return (strcmp (g_value_get_string (value1), g_value_get_string (value2)) == 0);
-	case G_TYPE_INT:
-		return g_value_get_int (value1) == g_value_get_int (value2);
+	case G_TYPE_INT64:
+		return g_value_get_int64 (value1) == g_value_get_int64 (value2);
 	case G_TYPE_DOUBLE:
 		/* does RDF define equality for floating point values? */
 		return g_value_get_double (value1) == g_value_get_double (value2);
@@ -1111,18 +1159,28 @@ get_property_values (TrackerProperty *property)
 	if (!resource_buffer->create) {
 		TrackerDBInterface *iface;
 		TrackerDBStatement *stmt;
-		TrackerDBResultSet *result_set;
+		TrackerDBResultSet *result_set = NULL;
 		const gchar        *table_name;
 		const gchar        *field_name;
+		GError             *error = NULL;
 
 		table_name = tracker_property_get_table_name (property);
 		field_name = tracker_property_get_name (property);
 
 		iface = tracker_db_manager_get_db_interface ();
 
-		stmt = tracker_db_interface_create_statement (iface, "SELECT \"%s\" FROM \"%s\" WHERE ID = ?", field_name, table_name);
-		tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-		result_set = tracker_db_statement_execute (stmt, NULL);
+		stmt = tracker_db_interface_create_statement (iface, &error, "SELECT \"%s\" FROM \"%s\" WHERE ID = ?", field_name, table_name);
+
+		if (stmt) {
+			tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+			result_set = tracker_db_statement_execute (stmt, &error);
+			g_object_unref (stmt);
+		}
+
+		if (error) {
+			g_warning ("Could not get property values: %s\n", error->message);
+			g_error_free (error);
+		}
 
 		/* We use a result_set instead of a cursor here because it's
 		 * possible that otherwise the cursor would remain open during
@@ -1140,7 +1198,7 @@ get_property_values (TrackerProperty *property)
 					if (tracker_property_get_data_type (property) == TRACKER_PROPERTY_TYPE_DATETIME) {
 						gint time;
 
-						time = g_value_get_int (&gvalue);
+						time = g_value_get_int64 (&gvalue);
 						g_value_unset (&gvalue);
 						g_value_init (&gvalue, TRACKER_TYPE_DATE_TIME);
 						/* UTC offset is irrelevant for comparison */
@@ -1153,7 +1211,6 @@ get_property_values (TrackerProperty *property)
 			}
 			g_object_unref (result_set);
 		}
-		g_object_unref (stmt);
 	}
 
 	return old_values;
@@ -1238,14 +1295,14 @@ string_to_gvalue (const gchar         *value,
 		g_value_set_string (gvalue, value);
 		break;
 	case TRACKER_PROPERTY_TYPE_INTEGER:
-		g_value_init (gvalue, G_TYPE_INT);
-		g_value_set_int (gvalue, atoi (value));
+		g_value_init (gvalue, G_TYPE_INT64);
+		g_value_set_int64 (gvalue, atoll (value));
 		break;
 	case TRACKER_PROPERTY_TYPE_BOOLEAN:
-		/* use G_TYPE_INT to be compatible with value stored in DB
+		/* use G_TYPE_INT64 to be compatible with value stored in DB
 		   (important for value_equal function) */
-		g_value_init (gvalue, G_TYPE_INT);
-		g_value_set_int (gvalue, strcmp (value, "true") == 0);
+		g_value_init (gvalue, G_TYPE_INT64);
+		g_value_set_int64 (gvalue, strcmp (value, "true") == 0);
 		break;
 	case TRACKER_PROPERTY_TYPE_DOUBLE:
 		g_value_init (gvalue, G_TYPE_DOUBLE);
@@ -1258,8 +1315,8 @@ string_to_gvalue (const gchar         *value,
 		break;
 	case TRACKER_PROPERTY_TYPE_RESOURCE:
 		object_id = ensure_resource_id (value, NULL);
-		g_value_init (gvalue, G_TYPE_INT);
-		g_value_set_int (gvalue, object_id);
+		g_value_init (gvalue, G_TYPE_INT64);
+		g_value_set_int64 (gvalue, object_id);
 		break;
 	default:
 		g_warn_if_reached ();
@@ -1316,8 +1373,8 @@ cache_set_metadata_decomposed (TrackerProperty  *property,
 			return FALSE;
 		}
 	} else {
-		g_value_init (&gvalue, G_TYPE_INT);
-		g_value_set_int (&gvalue, value_id);
+		g_value_init (&gvalue, G_TYPE_INT64);
+		g_value_set_int64 (&gvalue, value_id);
 	}
 
 	if (!value_set_add_value (old_values, &gvalue)) {
@@ -1325,13 +1382,35 @@ cache_set_metadata_decomposed (TrackerProperty  *property,
 		g_value_unset (&gvalue);
 	} else if (!multiple_values && old_values->n_values > 1) {
 		/* trying to add second value to single valued property */
+		GValue old_value = { 0 };
+		GValue new_value = { 0 };
+		const gchar *old_value_str = NULL;
+		const gchar *new_value_str = NULL;
 
-		g_value_unset (&gvalue);
+		g_value_init (&old_value, G_TYPE_STRING);
+		g_value_init (&new_value, G_TYPE_STRING);
+
+		/* Get both old and new values as strings letting glib do
+		 * whatever transformation needed */
+		if (g_value_transform (g_value_array_get_nth (old_values, 0), &old_value)) {
+			old_value_str = g_value_get_string (&old_value);
+		}
+		if (g_value_transform (g_value_array_get_nth (old_values, 1), &new_value)) {
+			new_value_str = g_value_get_string (&new_value);
+		}
 
 		g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_CONSTRAINT,
-		             "Unable to insert multiple values for subject `%s' and single valued property `%s'",
+		             "Unable to insert multiple values for subject `%s' and single valued property `%s' "
+		             "(old_value: '%s', new value: '%s')",
 		             resource_buffer->subject,
-		             field_name);
+		             field_name,
+		             old_value_str ? old_value_str : "<untransformable>",
+		             new_value_str ? new_value_str : "<untransformable>");
+
+		g_value_unset (&old_value);
+		g_value_unset (&new_value);
+		g_value_unset (&gvalue);
+
 	} else {
 		cache_insert_value (table_name, field_name, &gvalue,
 		                    graph != NULL ? ensure_resource_id (graph, NULL) : graph_id,
@@ -1379,8 +1458,8 @@ delete_metadata_decomposed (TrackerProperty  *property,
 			return FALSE;
 		}
 	} else {
-		g_value_init (&gvalue, G_TYPE_INT);
-		g_value_set_int (&gvalue, value_id);
+		g_value_init (&gvalue, G_TYPE_INT64);
+		g_value_set_int64 (&gvalue, value_id);
 	}
 
 	if (!value_set_remove_value (old_values, &gvalue)) {
@@ -1410,11 +1489,12 @@ cache_delete_resource_type (TrackerClass *class,
 {
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
-	TrackerDBResultSet *result_set;
+	TrackerDBResultSet *result_set = NULL;
 	TrackerProperty   **properties, *prop;
 	gboolean            found;
 	gint                i;
 	guint               p, n_props;
+	GError             *error = NULL;
 
 	iface = tracker_db_manager_get_db_interface ();
 
@@ -1432,14 +1512,22 @@ cache_delete_resource_type (TrackerClass *class,
 
 	/* retrieve all subclasses we need to remove from the subject
 	 * before we can remove the class specified as object of the statement */
-	stmt = tracker_db_interface_create_statement (iface,
+	stmt = tracker_db_interface_create_statement (iface, &error,
 	                                              "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdfs:Class_rdfs:subClassOf\".ID) "
 	                                              "FROM \"rdfs:Resource_rdf:type\" INNER JOIN \"rdfs:Class_rdfs:subClassOf\" ON (\"rdf:type\" = \"rdfs:Class_rdfs:subClassOf\".ID) "
 	                                              "WHERE \"rdfs:Resource_rdf:type\".ID = ? AND \"rdfs:subClassOf\" = (SELECT ID FROM Resource WHERE Uri = ?)");
-	tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
-	tracker_db_statement_bind_text (stmt, 1, tracker_class_get_uri (class));
-	result_set = tracker_db_statement_execute (stmt, NULL);
-	g_object_unref (stmt);
+
+	if (stmt) {
+		tracker_db_statement_bind_int (stmt, 0, resource_buffer->id);
+		tracker_db_statement_bind_text (stmt, 1, tracker_class_get_uri (class));
+		result_set = tracker_db_statement_execute (stmt, &error);
+		g_object_unref (stmt);
+	}
+
+	if (error) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+	}
 
 	if (result_set) {
 		do {
@@ -1534,6 +1622,11 @@ resource_buffer_switch (const gchar *graph,
 		GValue gvalue = { 0 };
 		gchar *subject_dup = NULL;
 
+		/* large INSERTs with thousands of resources could lead to
+		   high peak memory usage due to the update buffer
+		   flush the buffer if it already contains 1000 resources */
+		tracker_data_update_buffer_might_flush (NULL);
+
 		/* subject not yet in cache, retrieve or create ID */
 		resource_buffer = g_slice_new0 (TrackerDataUpdateBufferResource);
 		if (subject != NULL) {
@@ -1564,10 +1657,10 @@ resource_buffer_switch (const gchar *graph,
 			}
 		}
 
-		g_value_init (&gvalue, G_TYPE_INT);
-		g_value_set_int (&gvalue, tracker_data_update_get_next_modseq ());
+		g_value_init (&gvalue, G_TYPE_INT64);
+		g_value_set_int64 (&gvalue, tracker_data_update_get_next_modseq ());
 		cache_insert_value ("rdfs:Resource", "tracker:modified", &gvalue,
-		                    graph_id,
+		                    0,
 		                    FALSE, FALSE, FALSE);
 	}
 }
@@ -1827,7 +1920,6 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 		/* add value to metadata database */
 		change = cache_set_metadata_decomposed (property, object, 0, graph, 0, &actual_error);
 		if (actual_error) {
-			tracker_data_update_buffer_clear ();
 			g_propagate_error (error, actual_error);
 			return;
 		}
@@ -1898,7 +1990,6 @@ tracker_data_insert_statement_with_string (const gchar            *graph,
 	/* add value to metadata database */
 	change = cache_set_metadata_decomposed (property, object, 0, graph, 0, &actual_error);
 	if (actual_error) {
-		tracker_data_update_buffer_clear ();
 		g_propagate_error (error, actual_error);
 		return;
 	}
@@ -2043,7 +2134,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 {
 	TrackerDBInterface *iface;
 	TrackerDBStatement *stmt;
-	TrackerDBResultSet *result_set, *single_result, *multi_result;
+	TrackerDBResultSet *result_set = NULL, *single_result, *multi_result = NULL;
 	TrackerClass       *class;
 	gchar              *urn;
 	GString            *sql;
@@ -2052,6 +2143,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 	gboolean            first, bail_out = FALSE;
 	gint                resource_id;
 	guint               p, n_props;
+	GError             *actual_error = NULL;
 
 	/* We use result_sets instead of cursors here because it's possible
 	 * that otherwise the query of the outer cursor would be reused by the
@@ -2061,10 +2153,19 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 	/* DROP GRAPH <url> - url here is nie:url */
 
-	stmt = tracker_db_interface_create_statement (iface, "SELECT ID, (SELECT Uri FROM Resource WHERE ID = \"nie:DataObject\".ID) FROM \"nie:DataObject\" WHERE \"nie:DataObject\".\"nie:url\" = ?");
-	tracker_db_statement_bind_text (stmt, 0, url);
-	result_set = tracker_db_statement_execute (stmt, NULL);
-	g_object_unref (stmt);
+	stmt = tracker_db_interface_create_statement (iface, &actual_error,
+	                                              "SELECT ID, (SELECT Uri FROM Resource WHERE ID = \"nie:DataObject\".ID) FROM \"nie:DataObject\" WHERE \"nie:DataObject\".\"nie:url\" = ?");
+
+	if (stmt) {
+		tracker_db_statement_bind_text (stmt, 0, url);
+		result_set = tracker_db_statement_execute (stmt, &actual_error);
+		g_object_unref (stmt);
+	}
+
+	if (actual_error) {
+		g_propagate_error (error, actual_error);
+		return;
+	}
 
 	if (result_set) {
 		tracker_db_result_set_get (result_set, 0, &resource_id, -1);
@@ -2078,10 +2179,19 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 	properties = tracker_ontologies_get_properties (&n_props);
 
-	stmt = tracker_db_interface_create_statement (iface, "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdf:type\") FROM \"rdfs:Resource_rdf:type\" WHERE ID = ?");
-	tracker_db_statement_bind_int (stmt, 0, resource_id);
-	result_set = tracker_db_statement_execute (stmt, NULL);
-	g_object_unref (stmt);
+	stmt = tracker_db_interface_create_statement (iface, &actual_error,
+	                                              "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdf:type\") FROM \"rdfs:Resource_rdf:type\" WHERE ID = ?");
+
+	if (stmt) {
+		tracker_db_statement_bind_int (stmt, 0, resource_id);
+		result_set = tracker_db_statement_execute (stmt, &actual_error);
+		g_object_unref (stmt);
+	}
+
+	if (actual_error) {
+		g_propagate_error (error, actual_error);
+		return;
+	}
 
 	if (result_set) {
 		do {
@@ -2126,10 +2236,19 @@ tracker_data_delete_resource_description (const gchar *graph,
 			single_result = NULL;
 			if (!first) {
 				g_string_append_printf (sql, " FROM \"%s\" WHERE ID = ?", tracker_class_get_name (class));
-				stmt = tracker_db_interface_create_statement (iface, "%s", sql->str);
-				tracker_db_statement_bind_int (stmt, 0, resource_id);
-				single_result = tracker_db_statement_execute (stmt, NULL);
-				g_object_unref (stmt);
+				stmt = tracker_db_interface_create_statement (iface, &actual_error, "%s", sql->str);
+
+				if (stmt) {
+					tracker_db_statement_bind_int (stmt, 0, resource_id);
+					single_result = tracker_db_statement_execute (stmt, &actual_error);
+					g_object_unref (stmt);
+				}
+
+				if (actual_error) {
+					g_propagate_error (error, actual_error);
+					bail_out = TRUE;
+					break;
+				}
 			}
 
 			g_string_free (sql, TRUE);
@@ -2153,7 +2272,6 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 				if (!tracker_property_get_multiple_values (property)) {
 					gchar *value;
-					GError *new_error = NULL;
 
 					/* single value property, value in single_result_set */
 
@@ -2163,10 +2281,11 @@ tracker_data_delete_resource_description (const gchar *graph,
 						tracker_data_delete_statement (graph, urn,
 						                               tracker_property_get_uri (property),
 						                               value,
-						                               &new_error);
-						if (new_error) {
-							g_propagate_error (error, new_error);
+						                               &actual_error);
+						if (actual_error) {
+							g_propagate_error (error, actual_error);
 							bail_out = TRUE;
+							break;
 						}
 						g_free (value);
 					}
@@ -2182,27 +2301,35 @@ tracker_data_delete_resource_description (const gchar *graph,
 					                        " FROM \"%s\" WHERE ID = ?",
 					                        tracker_property_get_table_name (property));
 
-					stmt = tracker_db_interface_create_statement (iface, "%s", sql->str);
-					tracker_db_statement_bind_int (stmt, 0, resource_id);
-					multi_result = tracker_db_statement_execute (stmt, NULL);
-					g_object_unref (stmt);
+					stmt = tracker_db_interface_create_statement (iface, &actual_error, "%s", sql->str);
+
+					if (stmt) {
+						tracker_db_statement_bind_int (stmt, 0, resource_id);
+						multi_result = tracker_db_statement_execute (stmt, NULL);
+						g_object_unref (stmt);
+					}
+
+					if (actual_error) {
+						g_propagate_error (error, actual_error);
+						bail_out = TRUE;
+						break;
+					}
 
 					if (multi_result) {
 						do {
 							gchar *value;
-							GError *new_error = NULL;
 
 							tracker_db_result_set_get (multi_result, 0, &value, -1);
 
 							tracker_data_delete_statement (graph, urn,
 							                               tracker_property_get_uri (property),
 							                               value,
-							                               &new_error);
+							                               &actual_error);
 
 							g_free (value);
 
-							if (new_error) {
-								g_propagate_error (error, new_error);
+							if (actual_error) {
+								g_propagate_error (error, actual_error);
 								bail_out = TRUE;
 								break;
 							}
@@ -2360,7 +2487,7 @@ free_queued_statement (QueuedStatement *queued)
 }
 
 static GList*
-queue_statement (GList *queue, 
+queue_statement (GList *queue,
                  const gchar *graph,
                  const gchar *subject,
                  const gchar *predicate,
@@ -2404,10 +2531,10 @@ ontology_transaction_end (GList *ontology_queue,
 
 		/* store ontology in database */
 		tracker_data_ontology_process_statement (queued->graph,
-		                                         queued->subject, 
-		                                         queued->predicate, 
-		                                         queued->object, 
-		                                         queued->is_uri, 
+		                                         queued->subject,
+		                                         queued->predicate,
+		                                         queued->object,
+		                                         queued->is_uri,
 		                                         TRUE, TRUE);
 
 	}
@@ -2420,6 +2547,7 @@ ontology_transaction_end (GList *ontology_queue,
 			gint last_mod = 0;
 			TrackerDBInterface *iface;
 			TrackerDBStatement *stmt;
+			GError *error = NULL;
 
 			iface = tracker_db_manager_get_db_interface ();
 
@@ -2427,16 +2555,21 @@ ontology_transaction_end (GList *ontology_queue,
 			 * db. See tracker-data-manager.c for more info. */
 			last_mod = (gint) tracker_ontology_get_last_modified (ontology);
 
-			stmt = tracker_db_interface_create_statement (iface,
+			stmt = tracker_db_interface_create_statement (iface, &error,
 			        "UPDATE \"rdfs:Resource\" SET \"nao:lastModified\"= ? "
 			        "WHERE \"rdfs:Resource\".ID = "
 			        "(SELECT Resource.ID FROM Resource INNER JOIN \"rdfs:Resource\" "
 			        "ON \"rdfs:Resource\".ID = Resource.ID WHERE "
 			        "Resource.Uri = ?)");
 
-			tracker_db_statement_bind_int (stmt, 0, last_mod);
-			tracker_db_statement_bind_text (stmt, 1, ontology_uri);
-			tracker_db_statement_execute (stmt, NULL);
+			if (stmt) {
+				tracker_db_statement_bind_int (stmt, 0, last_mod);
+				tracker_db_statement_bind_text (stmt, 1, ontology_uri);
+				tracker_db_statement_execute (stmt, NULL);
+			} else {
+				g_warning ("%s", error->message);
+				g_error_free (error);
+			}
 		}
 	}
 
@@ -2532,15 +2665,18 @@ tracker_data_replay_journal (GHashTable          *classes,
 
 			iface = tracker_db_manager_get_db_interface ();
 
-			stmt = tracker_db_interface_create_statement (iface,
+			stmt = tracker_db_interface_create_statement (iface, &new_error,
 					                              "INSERT "
 					                              "INTO Resource "
 					                              "(ID, Uri) "
 					                              "VALUES (?, ?)");
-			tracker_db_statement_bind_int (stmt, 0, id);
-			tracker_db_statement_bind_text (stmt, 1, uri);
-			tracker_db_statement_execute (stmt, &new_error);
-			g_object_unref (stmt);
+
+			if (stmt) {
+				tracker_db_statement_bind_int (stmt, 0, id);
+				tracker_db_statement_bind_text (stmt, 1, uri);
+				tracker_db_statement_execute (stmt, &new_error);
+				g_object_unref (stmt);
+			}
 
 			if (new_error) {
 				g_warning ("Journal replay error: '%s'", new_error->message);
@@ -2683,7 +2819,6 @@ tracker_data_replay_journal (GHashTable          *classes,
 						cache_set_metadata_decomposed (property, NULL, object_id, NULL, graph_id, &new_error);
 
 						if (new_error) {
-							tracker_data_update_buffer_clear ();
 							g_warning ("Journal replay error: '%s'", new_error->message);
 							g_error_free (new_error);
 						}
