@@ -53,7 +53,7 @@
 #define TRACKER_DB_PAGE_SIZE_DONT_SET -1
 
 /* Set current database version we are working with */
-#define TRACKER_DB_VERSION_NOW        TRACKER_DB_VERSION_0_9_0
+#define TRACKER_DB_VERSION_NOW        TRACKER_DB_VERSION_0_9_8
 #define TRACKER_DB_VERSION_FILE       "db-version.txt"
 
 #define IN_USE_FILENAME               ".meta.isrunning"
@@ -84,7 +84,8 @@ typedef enum {
 	TRACKER_DB_VERSION_0_7_22,  /* fts-limits branch */
 	TRACKER_DB_VERSION_0_7_28,  /* RC1 + mto + nco:url */
 	TRACKER_DB_VERSION_0_8_0,   /* stable release */
-	TRACKER_DB_VERSION_0_9_0    /* unstable release */
+	TRACKER_DB_VERSION_0_9_0,   /* unstable release */
+	TRACKER_DB_VERSION_0_9_8    /* affiliation cardinality + volumes */
 } TrackerDBVersion;
 
 typedef struct {
@@ -415,7 +416,7 @@ db_manager_remove_all (gboolean rm_journal)
 {
 	guint i;
 
-	g_message ("Removing all database files");
+	g_message ("Removing all database/storage files");
 
 	/* Remove stamp files */
 	tracker_db_manager_set_first_index_done (FALSE);
@@ -886,7 +887,7 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 
 				if (cursor) {
 					if (tracker_db_cursor_iter_next (cursor, NULL)) {
-						if (g_strcmp0 (tracker_db_cursor_get_string (cursor, 0), "ok") != 0) {
+						if (g_strcmp0 (tracker_db_cursor_get_string (cursor, 0, NULL), "ok") != 0) {
 							must_recreate = TRUE;
 						}
 					}
@@ -1264,7 +1265,7 @@ tracker_db_manager_get_db_interface (void)
 			                                          TRACKER_DB_FULLTEXT,
 			                                          TRACKER_DB_CONTENTS);
 
-		tracker_db_interface_sqlite_fts_init (TRACKER_DB_INTERFACE_SQLITE (interface), FALSE);
+		tracker_db_interface_sqlite_fts_init (interface, FALSE);
 
 		g_static_private_set (&interface_data_key, interface, free_thread_interface);
 
