@@ -348,15 +348,15 @@ mount_add_new (TrackerStorage *storage,
 
 static gchar *
 mount_guess_content_type (GFile    *mount_root,
-                          GVolume  *volume,
-                          gboolean *is_optical,
-                          gboolean *is_multimedia,
-                          gboolean *is_blank)
+			  GVolume  *volume,
+			  gboolean *is_optical,
+			  gboolean *is_multimedia)
 {
 	GUnixMountEntry *entry;
 	gchar *content_type = NULL;
 	gchar *mount_path;
 	gchar **guess_type;
+	gint i;
 
 	/* This function has 2 purposes:
 	 *
@@ -375,15 +375,15 @@ mount_guess_content_type (GFile    *mount_root,
 
 	*is_optical = FALSE;
 	*is_multimedia = FALSE;
-	*is_blank = FALSE;
 
 	mount_path = g_file_get_path (mount_root);
 
 	/* FIXME: Try to assume we have a unix mount :(
 	 * EEK, once in a while, I have to write crack, oh well
 	 */
-	if (mount_path &&
-	    (entry = g_unix_mount_at (mount_path, NULL)) != NULL) {
+	entry = g_unix_mount_at (mount_path, NULL);
+
+	if (entry) {
 		const gchar *filesystem_type;
 		gchar *device_path = NULL;
 
@@ -454,61 +454,52 @@ mount_guess_content_type (GFile    *mount_root,
 	 * the media.
 	 */
 	guess_type = g_content_type_guess_for_tree (mount_root);
-	if (guess_type) {
-		gint i = 0;
 
-		while (!content_type && guess_type[i]) {
-			if (!g_strcmp0 (guess_type[i], "x-content/image-picturecd")) {
-				/* Images */
-				content_type = g_strdup (guess_type[i]);
-			} else if (!g_strcmp0 (guess_type[i], "x-content/video-bluray") ||
-			           !g_strcmp0 (guess_type[i], "x-content/video-dvd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/video-hddvd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/video-svcd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/video-vcd")) {
-				/* Videos */
-				*is_multimedia = TRUE;
-				content_type = g_strdup (guess_type[i]);
-			} else if (!g_strcmp0 (guess_type[i], "x-content/audio-cdda") ||
-			           !g_strcmp0 (guess_type[i], "x-content/audio-dvd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/audio-player")) {
-				/* Audios */
-				*is_multimedia = TRUE;
-				content_type = g_strdup (guess_type[i]);
-			} else if (!g_strcmp0 (guess_type[i], "x-content/blank-bd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/blank-cd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/blank-dvd") ||
-			           !g_strcmp0 (guess_type[i], "x-content/blank-hddvd")) {
-				/* Blank */
-				*is_blank = TRUE;
-				content_type = g_strdup (guess_type[i]);
-			} else if (!g_strcmp0 (guess_type[i], "x-content/software") ||
-			           !g_strcmp0 (guess_type[i], "x-content/unix-software") ||
-			           !g_strcmp0 (guess_type[i], "x-content/win32-software")) {
-				/* NOTE: This one is a guess, can we
-				 * have this content type on
-				 * none-optical mount points?
-				 */
-				content_type = g_strdup (guess_type[i]);
-			} else {
-				/* else, keep on with the next guess, if any */
-				i++;
-			}
+	for (i = 0; guess_type && guess_type[i]; i++) {
+		if (!g_strcmp0 (guess_type[i], "x-content/image-picturecd")) {
+			/* Images */
+			content_type = g_strdup (guess_type[i]);
+			break;
+		} else if (!g_strcmp0 (guess_type[i], "x-content/video-bluray") ||
+			   !g_strcmp0 (guess_type[i], "x-content/video-dvd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/video-hddvd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/video-svcd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/video-vcd")) {
+			/* Videos */
+			*is_multimedia = TRUE;
+			content_type = g_strdup (guess_type[i]);
+			break;
+		} else if (!g_strcmp0 (guess_type[i], "x-content/audio-cdda") ||
+			   !g_strcmp0 (guess_type[i], "x-content/audio-dvd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/audio-player")) {
+			/* Audios */
+			*is_multimedia = TRUE;
+			content_type = g_strdup (guess_type[i]);
+			break;
+		} else if (!g_strcmp0 (guess_type[i], "x-content/blank-bd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/blank-cd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/blank-dvd") ||
+			   !g_strcmp0 (guess_type[i], "x-content/blank-hddvd")) {
+			/* Blank */
+			content_type = g_strdup (guess_type[i]);
+			break;
+		} else if (!g_strcmp0 (guess_type[i], "x-content/software") ||
+			   !g_strcmp0 (guess_type[i], "x-content/unix-software") ||
+			   !g_strcmp0 (guess_type[i], "x-content/win32-software")) {
+			/* NOTE: This one is a guess, can we
+			 * have this content type on
+			 * none-optical mount points?
+			 */
+			content_type = g_strdup (guess_type[i]);
+			break;
+		} else if (!content_type) {
+			content_type = g_strdup (guess_type[i]);
+			break;
 		}
-
-		/* If we didn't have an exact match on possible guessed content types,
-		 *  then use the first one returned (best guess always first) if any */
-		if (!content_type && guess_type[0]) {
-			content_type = g_strdup (guess_type[0]);
-		}
-
-		g_strfreev (guess_type);
 	}
 
-	/* If none of the previous methods worked, return NULL content type and
-	 * set is_blank so that it's not indexed */
-	if (!content_type) {
-		*is_blank = TRUE;
+	if (guess_type) {
+		g_strfreev (guess_type);
 	}
 
 	return content_type;
@@ -560,28 +551,21 @@ mount_add (TrackerStorage *storage,
 		if (!uuid) {
 			gchar *content_type;
 			gboolean is_multimedia;
-			gboolean is_blank;
 
 			/* Optical discs usually won't have UUID in the GVolume */
-			content_type = mount_guess_content_type (root, volume, &is_optical, &is_multimedia, &is_blank);
+			content_type = mount_guess_content_type (root, volume, &is_optical, &is_multimedia);
 			is_removable = TRUE;
 
-			/* We don't index content which is video, music or blank */
-			if (!is_multimedia && !is_blank) {
+			/* We don't index content which is video or music, nothing to index */
+			if (!is_multimedia) {
 				uuid = g_compute_checksum_for_string (G_CHECKSUM_MD5,
 								      mount_name,
 								      -1);
 				g_debug ("  No UUID, generated:'%s' (based on mount name)", uuid);
-				g_debug ("  Assuming GVolume has removable media, if wrong report a bug! "
-				         "content type is '%s'",
-				         content_type);
+				g_debug ("  Assuming GVolume has removable media, if wrong report a bug!");
 			} else {
-				g_debug ("  Being ignored because mount with volume is music/video/blank "
-				         "(content type:%s, optical:%s, multimedia:%s, blank:%s)",
-				         content_type,
-				         is_optical ? "yes" : "no",
-				         is_multimedia ? "yes" : "no",
-				         is_blank ? "yes" : "no");
+				g_debug ("  Being ignored because mount is music/video, content type is '%s'",
+					 content_type);
 			}
 
 			g_free (content_type);
@@ -614,23 +598,17 @@ mount_add (TrackerStorage *storage,
 			if (mount_path) {
 				gchar *content_type;
 				gboolean is_multimedia;
-				gboolean is_blank;
 
-				content_type = mount_guess_content_type (root, volume, &is_optical, &is_multimedia, &is_blank);
+				content_type = mount_guess_content_type (root, volume, &is_optical, &is_multimedia);
 
-				/* Note: for GMounts without GVolume, is_blank should NOT be considered,
-				 * as it may give unwanted results... */
 				if (!is_multimedia) {
 					uuid = g_compute_checksum_for_string (G_CHECKSUM_MD5,
 									      mount_path,
 									      -1);
 					g_debug ("  No UUID, generated:'%s' (based on mount path)", uuid);
 				} else {
-					g_debug ("  Being ignored because mount is music/video "
-					         "(content type:%s, optical:%s, multimedia:%s)",
-					         content_type,
-					         is_optical ? "yes" : "no",
-					         is_multimedia ? "yes" : "no");
+					g_debug ("  Being ignored because mount is music/video, content type is '%s'",
+						 content_type);
 				}
 
 				g_free (content_type);
@@ -773,7 +751,7 @@ get_mount_point_by_uuid_foreach (gpointer key,
 
 	/* is mount of the type we're looking for? */
 	if ((gr->exact_match && mount_type == gr->type) ||
-	    (!gr->exact_match && ((mount_type & gr->type) == gr->type))) {
+	    (!gr->exact_match && (mount_type & gr->type))) {
 		gchar *normalized_mount_point;
 		gint len;
 
@@ -801,8 +779,8 @@ get_mount_point_by_uuid_foreach (gpointer key,
  **/
 GSList *
 tracker_storage_get_device_roots (TrackerStorage     *storage,
-                                  TrackerStorageType  type,
-                                  gboolean            exact_match)
+				  TrackerStorageType  type,
+				  gboolean            exact_match)
 {
 	TrackerStoragePrivate *priv;
 	GetRoots gr;
@@ -834,8 +812,8 @@ tracker_storage_get_device_roots (TrackerStorage     *storage,
  **/
 GSList *
 tracker_storage_get_device_uuids (TrackerStorage     *storage,
-                                  TrackerStorageType  type,
-                                  gboolean            exact_match)
+				  TrackerStorageType  type,
+				  gboolean            exact_match)
 {
 	TrackerStoragePrivate *priv;
 	GHashTableIter iter;
@@ -864,7 +842,7 @@ tracker_storage_get_device_uuids (TrackerStorage     *storage,
 
 		/* is mount of the type we're looking for? */
 		if ((exact_match && mount_type == type) ||
-		    (!exact_match && ((mount_type & type) == type))) {
+		    (!exact_match && (mount_type & type))) {
 			uuids = g_slist_prepend (uuids, g_strdup (uuid));
 		}
 	}
@@ -903,6 +881,44 @@ tracker_storage_get_mount_point_for_uuid (TrackerStorage *storage,
 	return info->mount_point;
 }
 
+/**
+ * tracker_storage_get_type_for_uuid:
+ * @storage: A #TrackerStorage
+ * @uuid: A string pointer to the UUID for the %GVolume.
+ *
+ * Returns: The type flags for @uuid.
+ **/
+TrackerStorageType
+tracker_storage_get_type_for_uuid (TrackerStorage     *storage,
+                                   const gchar        *uuid)
+{
+	TrackerStoragePrivate *priv;
+	GNode *node;
+	TrackerStorageType type = 0;
+
+	g_return_val_if_fail (TRACKER_IS_STORAGE (storage), 0);
+	g_return_val_if_fail (uuid != NULL, 0);
+
+	priv = TRACKER_STORAGE_GET_PRIVATE (storage);
+
+	node = g_hash_table_lookup (priv->mounts_by_uuid, uuid);
+
+	if (node) {
+		MountInfo *info;
+
+		info = node->data;
+
+		if (info->removable) {
+			type |= TRACKER_STORAGE_REMOVABLE;
+		}
+		if (info->optical) {
+			type |= TRACKER_STORAGE_OPTICAL;
+		}
+	}
+
+	return type;
+}
+
 /**
  * tracker_storage_get_uuid_for_file:
  * @storage: A #TrackerStorage
